==> tree-manager-service-1.0.0-20120818.213718-27-sources.jar: org/gcube/data/tm/activationrecord/ActivationRecordBody.java <==
/**
 * 
 */
package org.gcube.data.tm.activationrecord;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import org.gcube.data.tml.Constants;
import org.gcube.data.tml.clients.BindingParameters;

/**
 * The body of an activation record.
 * 
 * @author Fabio Simeoni
 *
 */
@XmlRootElement(name="Record", namespace=Constants.COMMON_NS)
@XmlType(propOrder={"createdBy","parameters"})
public class ActivationRecordBody {

	private String createdBy;
	private BindingParameters parameters;
	
	/**Creates an instance.*/
	public ActivationRecordBody() {} //necessary for deserialisation
	
	/**
	 * Returns the identifier of record's creator.
	 * @return the identifier.
	 */
	public String getCreatedBy() {
		return createdBy;
	}
	
	/**
	 * Sets the identifier of the record's creator.
	 * @param id the identifier.
	 */
	@XmlElement public void setCreatedBy(String id) {
		this.createdBy = id;
	}
	
	/**
	 * Returns the parameters of the activation.
	 * @return the parameters.
	 */
	public BindingParameters getParameters() {
		return parameters;
	}
	
	/**
	 * Sets the parameters of the activation.
	 * @param parameters the parameters.
	 */
	@XmlElement 
	public void setParameters(BindingParameters parameters) {
		this.parameters = parameters;
	}
	
	/**
	 * Creates an instance from the identifier of the record's creator and
	 * the activation's parameters.
	 * @param id the identifier.
	 * @param params the parameters.
	 */
	public ActivationRecordBody(String id,BindingParameters params) {
		createdBy=id;
		parameters=params;
	}

}

==> tree-manager-service-2.0.0-20121022.220608-45-sources.jar: org/gcube/data/tm/activationrecord/ActivationRecordBody.java <==
/**
 * 
 */
package org.gcube.data.tm.activationrecord;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import org.gcube.data.tml.Constants;
import org.gcube.data.tml.proxies.BindParams;

/**
 * The body of an activation record.
 * 
 * @author Fabio Simeoni
 *
 */
@XmlRootElement(name="Record", namespace=Constants.COMMON_NS)
@XmlType(propOrder={"createdBy","parameters"})
public class ActivationRecordBody {

	private String createdBy;
	private BindParams parameters;
	
	/**Creates an instance.*/
	public ActivationRecordBody() {} //necessary for deserialisation
	
	/**
	 * Returns the identifier of record's creator.
	 * @return the identifier.
	 */
	public String getCreatedBy() {
		return createdBy;
	}
	
	/**
	 * Sets the identifier of the record's creator.
	 * @param id the identifier.
	 */
	@XmlElement public void setCreatedBy(String id) {
		this.createdBy = id;
	}
	
	/**
	 * Returns the parameters of the activation.
	 * @return the parameters.
	 */
	public BindParams getParameters() {
		return parameters;
	}
	
	/**
	 * Sets the parameters of the activation.
	 * @param parameters the parameters.
	 */
	@XmlElement 
	public void setParameters(BindParams parameters) {
		this.parameters = parameters;
	}
	
	/**
	 * Creates an instance from the identifier of the record's creator and
	 * the activation's parameters.
	 * @param id the identifier.
	 * @param params the parameters.
	 */
	public ActivationRecordBody(String id,BindParams params) {
		createdBy=id;
		parameters=params;
	}

}
